# Laz

A CLI tool to configure and run parameterized actions against targets.

## Installation

Laz currently requires Python 3.8+.

```shell
pip3 install --user laz
```

You can check your installation by running:

```shell
laz version
```
